module NbaRb
  class League
    class << self
      attr_accessor :default, :NBA
    end

    @NBA = '00'
    @default = @NBA
  end

  class PerMode
    class << self
      attr_accessor :totals,
                    :per_game,
                    :minutes_per,
                    :per_48,
                    :per_40,
                    :per_36,
                    :per_minute,
                    :per_possession,
                    :per_play,
                    :per_100_possessions,
                    :per_100_plays,
                    :default
    end

    @totals = 'Totals'
    @per_game = 'PerGame'
    @minutes_per = 'MinutesPer'
    @per_48 = 'Per48'
    @per_40 = 'Per40'
    @per_36 = 'Per36'
    @per_minute = 'PerMinute'
    @per_possession = 'PerPossession'
    @per_play = 'PerPlay'
    @per_100_possessions = 'Per100Possessions'
    @per_100_plays = 'Per100Plays'
    @default = @per_game
  end

  class SeasonType
    class << self
      attr_accessor :default,
                    :playoffs,
                    :regular
    end

    @regular = 'Regular Season'
    @playoffs = 'Playoffs'
    @default = @regular
  end

  class MeasureType
    class << self
      attr_accessor :default,
                    :advanced,
                    :base,
                    :misc,
                    :four_factors,
                    :scoring,
                    :opponent,
                    :usage
    end

    @base = 'Base'
    @advanced = 'Advanced'
    @misc = 'Misc'
    @four_factors = 'Four Factors'
    @scoring = 'Scoring'
    @opponent = 'Opponent'
    @usage = 'Usage'
    @default = @base
  end

  class GroupQuantity
    class << self
      attr_accessor :default
    end

    @default = 5
  end

  class Outcome
    class << self
      attr_accessor :default, :win, :loss
    end

    @default = ''
    @win = 'W'
    @loss = 'L'
  end

  class Location
    class << self
      attr_accessor :default, :home, :away
    end

    @default = ''
    @home = 'Home'
    @away = 'Road'
  end

  class SeasonSegment
    class << self
      attr_accessor :default,
                    :entire_season,
                    :pre_all_star,
                    :post_all_star
    end
    @default = ''

    @entire_season = ''
    @pre_all_star = 'Pre All-Star'
    @post_all_star = 'Post All-Star'
  end

  class DateFrom
    class << self
      attr_accessor :default
    end

    @default = ''
  end

  class DateTo
    class << self
      attr_accessor :default
    end

    @default = ''
  end

  class VsConference
    class << self
      attr_accessor :default, :all, :east, :west
    end

    @default = ''
    @all = ''
    @east = 'East'
    @west = 'West'
  end

  class VsDivision
    class << self
      attr_accessor :default,
                    :all,
                    :atlantic,
                    :central,
                    :northwest,
                    :pacific,
                    :southeast,
                    :southwest
    end

    @default = ''
    @all = ''
    @atlantic = 'Atlantic'
    @central = 'Central'
    @northwest = 'Northwest'
    @pacific = 'Pacific'
    @southeast = 'Southeast'
    @southwest = 'Southwest'
  end

  class GameSegment
    class << self
      attr_accessor :default,
                    :entire_game,
                    :first_half,
                    :second_half,
                    :overtime
    end

    @default = ''
    @entire_game = ''
    @first_half = 'First Half'
    @second_half = 'Second Half'
    @overtime = 'Overtime'
  end

  class ShotClockRange
    class << self
      attr_accessor :default,
                    :all_ranges,
                    :shot_clock_off
    end

    @default = ''
    @all_ranges = ''
    @shot_clock_off = 'ShotClock Off'

    def get(n)
      if n > 24 or n < 0
        return ''
      elsif 22 <= n <= 24
        return '24-22'
      elsif 18 <= n < 22
        return '22-18 Very Early'
      elsif 15 <= n < 18
        return '18-15 Early'
      elsif 7 <= n < 15
        return '15-7 Average'
      elsif 4 <= n < 7
        return '7-4 Late'
      elsif 0 <= n < 4
        return '4-0 Very Late'
      end
    end
  end

  class PlusMinus
    class << self
      attr_accessor :default
    end

    @default = 'N'
  end

  class PaceAdjust
    class << self
      attr_accessor :default
    end

    @default = 'N'
  end

  class Rank
    class << self
      attr_accessor :default
    end

    @default = 'N'
  end

  class OpponentTeamID
    class << self
      attr_accessor :default
    end

    @default = '0'
  end

  class Period
    class << self
      attr_accessor :default,
                    :all_quarters,
                    :first_quarter,
                    :second_quarter,
                    :third_quarter,
                    :fourth_quarter
    end

    @default = '0'
    @all_quarters = '0'
    @first_quarter = '1'
    @second_quarter = '2'
    @third_quarter = '3'
    @fourth_quarter = '4'

    def overtime(n)
      str(4 + n)
    end
  end

  class LastNGames
    class << self
      attr_accessor :default
    end

    @default = '0'
  end


  class PlayoffRound
    class << self
      attr_accessor :default,
                    :all,
                    :quarter_finals,
                    :semi_finals,
                    :conference_finals,
                    :finals
    end

    @default = '0'
    @all = '0'
    @quarter_finals = '1'
    @semi_finals = '2'
    @conference_finals = '3'
    @finals = '4'
  end

  class Month
    class << self
      attr_accessor :default,
                    :all,
                    :october,
                    :november,
                    :december,
                    :january,
                    :february,
                    :march,
                    :april,
                    :may,
                    :june,
                    :july,
                    :august,
                    :september
    end

    @default = '0'
    @all = '0'
    @october = '1'
    @november = '2'
    @december = '3'
    @january = '4'
    @february = '5'
    @march = '6'
    @april = '7'
    @may = '8'
    @june = '9'
    @july = '10'
    @august = '11'
    @september = '12'
  end

  class RangeType
    class << self
      attr_accessor :default
    end

    @default = '0'
  end

  class StartRange
    class << self
      attr_accessor :default
    end

    @default = '0'
  end

  class EndRange
    class << self
      attr_accessor :default
    end

    @default = '0'
  end

  class StartPeriod < Period
  end

  class EndPeriod < Period
  end

TEAMS = {
    'ATL' => {
        'abbr' => 'ATL',
        'city' => 'Atlanta',
        'code' => 'hawks',
        'conference' => 'Eastern',
        'displayAbbr' => 'ATL',
        'displayConference' => 'Eastern',
        'division' => 'Southeast',
        'id' => '1610612737',
        'name' => 'Hawks',
        'color' => 'E2373E',
        'colors' => ['E2373E', '002A5C', 'BAC4CA']
    }, 'BOS' => {
        'abbr' => 'BOS',
        'city' => 'Boston',
        'code' => 'celtics',
        'conference' => 'Eastern',
        'displayAbbr' => 'BOS',
        'displayConference' => 'Eastern',
        'division' => 'Atlantic',
        'id' => '1610612738',
        'name' => 'Celtics',
        'color' => '007239',
        'colors' => ['007239', 'AE8445', '982527', '000000']
    }, 'BKN' => {
        'abbr' => 'BKN',
        'city' => 'Brooklyn',
        'code' => 'nets',
        'conference' => 'Eastern',
        'displayAbbr' => 'BKN',
        'displayConference' => 'Eastern',
        'division' => 'Atlantic',
        'id' => '1610612751',
        'name' => 'Nets',
        'color' => '000000',
        'colors' => ['000000', 'FFFFFF']
    }, 'CHA' => {
        'abbr' => 'CHA',
        'city' => 'Charlotte',
        'code' => 'hornets',
        'conference' => 'Eastern',
        'displayAbbr' => 'CHA',
        'displayConference' => 'Eastern',
        'division' => 'Southeast',
        'id' => '1610612766',
        'name' => 'Hornets',
        'color' => '00848E',
        'colors' => ['00848E', '260F54', 'CCCCCC']
    }, 'CHI' => {
        'abbr' => 'CHI',
        'city' => 'Chicago',
        'code' => 'bulls',
        'conference' => 'Eastern',
        'displayAbbr' => 'CHI',
        'displayConference' => 'Eastern',
        'division' => 'Central',
        'id' => '1610612741',
        'name' => 'Bulls',
        'color' => 'C60033',
        'colors' => ['C60033', '000000']
    }, 'CLE' => {
        'abbr' => 'CLE',
        'city' => 'Cleveland',
        'code' => 'cavaliers',
        'conference' => 'Eastern',
        'displayAbbr' => 'CLE',
        'displayConference' => 'Eastern',
        'division' => 'Central',
        'id' => '1610612739',
        'name' => 'Cavaliers',
        'color' => '860038',
        'colors' => ['860038', '002D62', 'FDBA31']
    }, 'DAL' => {
        'abbr' => 'DAL',
        'city' => 'Dallas',
        'code' => 'mavericks',
        'conference' => 'Western',
        'displayAbbr' => 'DAL',
        'displayConference' => 'Western',
        'division' => 'Southwest',
        'id' => '1610612742',
        'name' => 'Mavericks',
        'color' => '0063AF',
        'colors' => ['0063AF', 'BAC4CA', '000000']
    }, 'DEN' => {
        'abbr' => 'DEN',
        'city' => 'Denver',
        'code' => 'nuggets',
        'conference' => 'Western',
        'displayAbbr' => 'DEN',
        'displayConference' => 'Western',
        'division' => 'Northwest',
        'id' => '1610612743',
        'name' => 'Nuggets',
        'color' => '559FD6',
        'colors' => ['559FD6', '006BB7', 'FEA927']
    }, 'DET' => {
        'abbr' => 'DET',
        'city' => 'Detroit',
        'code' => 'pistons',
        'conference' => 'Eastern',
        'displayAbbr' => 'DET',
        'displayConference' => 'Eastern',
        'division' => 'Central',
        'id' => '1610612765',
        'name' => 'Pistons',
        'color' => 'EC003D',
        'colors' => ['EC003D', '0058A6', '001D4A']
    }, 'GSW' => {
        'abbr' => 'GSW',
        'city' => 'Golden State',
        'code' => 'warriors',
        'conference' => 'Western',
        'displayAbbr' => 'GSW',
        'displayConference' => 'Western',
        'division' => 'Pacific',
        'id' => '1610612744',
        'name' => 'Warriors',
        'color' => '0068B3',
        'colors' => ['0068B3', 'FFC423']
    }, 'HOU' => {
        'abbr' => 'HOU',
        'city' => 'Houston',
        'code' => 'rockets',
        'conference' => 'Western',
        'displayAbbr' => 'HOU',
        'displayConference' => 'Western',
        'division' => 'Southwest',
        'id' => '1610612745',
        'name' => 'Rockets',
        'color' => 'C60033',
        'colors' => ['C60033', '000000']
    }, 'IND' => {
        'abbr' => 'IND',
        'city' => 'Indiana',
        'code' => 'pacers',
        'conference' => 'Eastern',
        'displayAbbr' => 'IND',
        'displayConference' => 'Eastern',
        'division' => 'Central',
        'id' => '1610612754',
        'name' => 'Pacers',
        'color' => '001D4A',
        'colors' => ['001D4A', 'FEAC2D', 'B0B2B5']
    }, 'LAC' => {
        'abbr' => 'LAC',
        'city' => 'Los Angeles',
        'code' => 'clippers',
        'conference' => 'Western',
        'displayAbbr' => 'LAC',
        'displayConference' => 'Western',
        'division' => 'Pacific',
        'id' => '1610612746',
        'name' => 'Clippers',
        'color' => '00559A',
        'colors' => ['00559A', 'EC003D']
    }, 'LAL' => {
        'abbr' => 'LAL',
        'city' => 'Los Angeles',
        'code' => 'lakers',
        'conference' => 'Western',
        'displayAbbr' => 'LAL',
        'displayConference' => 'Western',
        'division' => 'Pacific',
        'id' => '1610612747',
        'name' => 'Lakers',
        'color' => 'FEA927',
        'colors' => ['FEA927', '42186E', '000000']
    }, 'MEM' => {
        'abbr' => 'MEM',
        'city' => 'Memphis',
        'code' => 'grizzlies',
        'conference' => 'Western',
        'displayAbbr' => 'MEM',
        'displayConference' => 'Western',
        'division' => 'Southwest',
        'id' => '1610612763',
        'name' => 'Grizzlies',
        'color' => '182A48',
        'colors' => ['182A48', '4C78AD', 'FEA927', 'AAC8E5']
    }, 'MIA' => {
        'abbr' => 'MIA',
        'city' => 'Miami',
        'code' => 'heat',
        'conference' => 'Eastern',
        'displayAbbr' => 'MIA',
        'displayConference' => 'Eastern',
        'division' => 'Southeast',
        'id' => '1610612748',
        'name' => 'Heat',
        'color' => '98002E',
        'colors' => ['98002E', 'F88D1D', '000000']
    }, 'MIL' => {
        'abbr' => 'MIL',
        'city' => 'Milwaukee',
        'code' => 'bucks',
        'conference' => 'Eastern',
        'displayAbbr' => 'MIL',
        'displayConference' => 'Eastern',
        'division' => 'Central',
        'id' => '1610612749',
        'name' => 'Bucks',
        'color' => 'C41230',
        'colors' => ['C41230', '003815', 'BAC4CA']
    }, 'MIN' => {
        'abbr' => 'MIN',
        'city' => 'Minnesota',
        'code' => 'timberwolves',
        'conference' => 'Western',
        'displayAbbr' => 'MIN',
        'displayConference' => 'Western',
        'division' => 'Northwest',
        'id' => '1610612750',
        'name' => 'Timberwolves',
        'color' => '#003F70',
        'colors' => ['003F70', '006F42', 'BAC4CA', 'FFE211', 'DE2032', '000000']
    }, 'NOP' => {
        'abbr' => 'NOP',
        'city' => 'New Orleans',
        'code' => 'pelicans',
        'conference' => 'Western',
        'displayAbbr' => 'NOP',
        'displayConference' => 'Western',
        'division' => 'Southwest',
        'id' => '1610612740',
        'name' => 'Pelicans',
        'color' => '#002B5C',
        'colors' => ['002B5C', 'B4975A', 'E13A3E']
    }, 'NYK' => {
        'abbr' => 'NYK',
        'city' => 'New York',
        'code' => 'knicks',
        'conference' => 'Eastern',
        'displayAbbr' => 'NYK',
        'displayConference' => 'Eastern',
        'division' => 'Atlantic',
        'id' => '1610612752',
        'name' => 'Knicks',
        'color' => 'F3571F',
        'colors' => ['F3571F', '0067B2', 'BAC4CA']
    }, 'OKC' => {
        'abbr' => 'OKC',
        'city' => 'Oklahoma City',
        'code' => 'thunder',
        'conference' => 'Western',
        'displayAbbr' => 'OKC',
        'displayConference' => 'Western',
        'division' => 'Northwest',
        'id' => '1610612760',
        'name' => 'Thunder',
        'color' => 'FDBB30',
        'colors' => ['FDBB30', 'F05133', '007DC3', '002D62']
    }, 'ORL' => {
        'abbr' => 'ORL',
        'city' => 'Orlando',
        'code' => 'magic',
        'conference' => 'Eastern',
        'displayAbbr' => 'ORL',
        'displayConference' => 'Eastern',
        'division' => 'Southeast',
        'id' => '1610612753',
        'name' => 'Magic',
        'color' => '006BB7',
        'colors' => ['006BB7', 'BAC4CA', '000000']
    }, 'PHI' => {
        'abbr' => 'PHI',
        'city' => 'Philadelphia',
        'code' => 'sixers',
        'conference' => 'Eastern',
        'displayAbbr' => 'PHI',
        'displayConference' => 'Eastern',
        'division' => 'Atlantic',
        'id' => '1610612755',
        'name' => 'Sixers',
        'color' => 'EC003D',
        'colors' => ['EC003D', '00559A', 'BAC4CA']
    }, 'PHX' => {
        'abbr' => 'PHX',
        'city' => 'Phoenix',
        'code' => 'suns',
        'conference' => 'Western',
        'displayAbbr' => 'PHX',
        'displayConference' => 'Western',
        'division' => 'Pacific',
        'id' => '1610612756',
        'name' => 'Suns',
        'color' => 'E45F1F',
        'colors' => ['E45F1F', 'F89F1B', 'BAC4CA', '000000']
    }, 'POR' => {
        'abbr' => 'POR',
        'city' => 'Portland',
        'code' => 'blazers',
        'conference' => 'Western',
        'displayAbbr' => 'POR',
        'displayConference' => 'Western',
        'division' => 'Northwest',
        'id' => '1610612757',
        'name' => 'Trail Blazers',
        'color' => 'DE2032',
        'colors' => ['DE2032', 'BAC4CA', '000000']
    }, 'SAC' => {
        'abbr' => 'SAC',
        'city' => 'Sacramento',
        'code' => 'kings',
        'conference' => 'Western',
        'displayAbbr' => 'SAC',
        'displayConference' => 'Western',
        'division' => 'Pacific',
        'id' => '1610612758',
        'name' => 'Kings',
        'color' => '542E91',
        'colors' => ['542E91', 'BAC4CA', '000000']
    }, 'SAS' => {
        'abbr' => 'SAS',
        'city' => 'San Antonio',
        'code' => 'spurs',
        'conference' => 'Western',
        'displayAbbr' => 'SAS',
        'displayConference' => 'Western',
        'division' => 'Southwest',
        'id' => '1610612759',
        'name' => 'Spurs',
        'color' => '#BA24CA',
        'colors' => ['BA24CA', '000000']
    }, 'TOR' => {
        'abbr' => 'TOR',
        'city' => 'Toronto',
        'code' => 'raptors',
        'conference' => 'Eastern',
        'displayAbbr' => 'TOR',
        'displayConference' => 'Eastern',
        'division' => 'Atlantic',
        'id' => '1610612761',
        'name' => 'Raptors',
        'color' => 'C60033',
        'colors' => ['C60033', 'BAC4CA']
    }, 'UTA' => {
        'abbr' => 'UTA',
        'city' => 'Utah',
        'code' => 'jazz',
        'conference' => 'Western',
        'displayAbbr' => 'UTA',
        'displayConference' => 'Western',
        'division' => 'Northwest',
        'id' => '1610612762',
        'name' => 'Jazz',
        'color' => '#002A5C',
        'colors' => ['002A5C', '004812', 'FCB034', 'BACA4CA']
    }, 'WAS' => {
        'abbr' => 'WAS',
        'city' => 'Washington',
        'code' => 'wizards',
        'conference' => 'Eastern',
        'displayAbbr' => 'WAS',
        'displayConference' => 'Eastern',
        'division' => 'Southeast',
        'id' => '1610612764',
        'name' => 'Wizards',
        'color' => '002A5B',
        'colors' => ['002A5B', 'E21836', 'BAC4CA']
    }
}
end
